<?php

add_action( 'admin_init', 'theme_options_init' );
add_action( 'admin_menu', 'theme_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function theme_options_init(){
	register_setting( 'rdeck_options', 'rdeck_theme_options', 'rdeck_theme_options_validate' );
}

/**
 * Load up the menu page
 */
function theme_options_add_page() {
	add_theme_page( __( 'Theme Options', 'rdeck' ), __( 'Theme Options', 'rdeck' ), 'edit_theme_options', 'theme_options', 'theme_options_do_page' );
}

/**
 * Create arrays for our select and radio options
 */
$select_options = array(
	'0' => array(
		'value' =>	'0',
		'label' => __( 'Zero', 'rdeck' )
	),
	'1' => array(
		'value' =>	'1',
		'label' => __( 'One', 'rdeck' )
	),
	'2' => array(
		'value' => '2',
		'label' => __( 'Two', 'rdeck' )
	),
	'3' => array(
		'value' => '3',
		'label' => __( 'Three', 'rdeck' )
	),
	'4' => array(
		'value' => '4',
		'label' => __( 'Four', 'rdeck' )
	),
	'5' => array(
		'value' => '5',
		'label' => __( 'Five', 'rdeck' )
	)
);


/**
 * Create the options page
 */
function theme_options_do_page() {
	global $select_options;

	if ( ! isset( $_REQUEST['settings-updated'] ) )
		$_REQUEST['settings-updated'] = false;

	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" . get_current_theme() . __( ' Theme Options', 'rdeck' ) . "</h2>"; ?>

		<?php if ( false !== $_REQUEST['settings-updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved', 'rdeck' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'rdeck_options' ); ?>
			<?php $options = get_option( 'rdeck_theme_options' ); ?>

			<table class="form-table">
            
            <?php
				/**
				 * Social Links checkbox option
				 */
				?>
            <tr valign="top"><th scope="row"><?php _e( 'Enable Social Links', 'rdeck' ); ?></th>
					<td>
						<input id="rdeck_theme_options[social]" name="rdeck_theme_options[social]" type="checkbox" value="1" <?php checked( '1', $options['social'] ); ?> />
						<label class="description" for="rdeck_theme_options[social]"><?php _e( 'Check this box to enable social links, to be used in the header above site title.', 'rdeck' ); ?></label>
					</td>
				</tr>
                
             <?php
				/**
				 * Twitter Profile URL text input option
				 */
				?>   
             <tr valign="top"><th scope="row"><?php _e( 'Twitter Profile URL', 'rdeck' ); ?></th>
					<td>
						<input id="rdeck_theme_options[twitter]" class="regular-text" type="text" name="rdeck_theme_options[twitter]" value="<?php esc_attr_e( $options['twitter'] ); ?>" />
						<label class="description" for="rdeck_theme_options[twitter]"><?php _e( 'Your Twitter profile URL, ie --> http://twitter.com/responsivedeck', 'rdeck' ); ?></label>
					</td>
				</tr>
                
                <?php
				/**
				 * Dribbble Profile URL text input option
				 */
				?>   
             <tr valign="top"><th scope="row"><?php _e( 'Dribbble Profile URL', 'rdeck' ); ?></th>
					<td>
						<input id="rdeck_theme_options[dribbble]" class="regular-text" type="text" name="rdeck_theme_options[dribbble]" value="<?php esc_attr_e( $options['dribbble'] ); ?>" />
						<label class="description" for="rdeck_theme_options[dribbble]"><?php _e( 'Your Dribbble profile URL, ie --> http://dribbble.com/your-profile', 'rdeck' ); ?></label>
					</td>
				</tr>
                
                <?php
				/**
				 * Facebook Page URL text input option
				 */
				?>   
             <tr valign="top"><th scope="row"><?php _e( 'Facebook Page URL', 'rdeck' ); ?></th>
					<td>
						<input id="rdeck_theme_options[facebook]" class="regular-text" type="text" name="rdeck_theme_options[facebook]" value="<?php esc_attr_e( $options['facebook'] ); ?>" />
						<label class="description" for="rdeck_theme_options[facebook]"><?php _e( 'Your Facebook page URL, ie --> http://www.facebook.com/responsivedeck', 'rdeck' ); ?></label>
					</td>
				</tr>
                
                <?php
				/**
				 * Feedburner RSS URL text input option
				 */
				?>   
             <tr valign="top"><th scope="row"><?php _e( 'Feedburner URL', 'rdeck' ); ?></th>
					<td>
						<input id="rdeck_theme_options[feedburner]" class="regular-text" type="text" name="rdeck_theme_options[feedburner]" value="<?php esc_attr_e( $options['feedburner'] ); ?>" />
						<label class="description" for="rdeck_theme_options[feedburner]"><?php _e( 'Paste your Feedburner (RSS) URL, ie --> http://feeds.feedburner.com/ResponsiveDeck', 'rdeck' ); ?></label>
					</td>
				</tr>
                
                <?php
				/**
				 * Text Logo checkbox option
				 */
				?>
            <tr valign="top"><th scope="row"><?php _e( 'Enable Plain Text Logo', 'rdeck' ); ?></th>
					<td>
						<input id="rdeck_theme_options[txt_logo]" name="rdeck_theme_options[txt_logo]" type="checkbox" value="1" <?php checked( '1', $options['txt_logo'] ); ?> />
						<label class="description" for="rdeck_theme_options[txt_logo]"><?php _e( 'Check this box to use a plain text logo rather than an image.', 'rdeck' ); ?></label>
					</td>
				</tr>

				 <?php
				/**
				 * Custom Image Logo URL text input option
				 */
				?>   
             <tr valign="top"><th scope="row"><?php _e( 'Upload Logo', 'rdeck' ); ?></th>
					<td>
						<input id="rdeck_theme_options[custom_logo]" class="regular-text" type="text" name="rdeck_theme_options[custom_logo]" value="<?php esc_attr_e( $options['custom_logo'] ); ?>" />
						<label class="description" for="rdeck_theme_options[custom_logo]"><?php _e( 'Enter an URL eg. (http://site-url.com/site_logo.jpg) or upload an image for the logo image.', 'rdeck' ); ?></label>
                        <br/>
                <em>
                <a href="<?php bloginfo("url"); ?>/wp-admin/media-new.php" target="_blank">Upload your logo</a>
				</em>
                
                <span><br/>
                <img src="<?php echo $options['custom_logo'] ?>" alt=""/></span>
					</td>
                </tr>
                
                                
                <?php
				/**
				 * Number of Featured Posts select input option
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Select Number of Featured', 'rdeck' ); ?></th>
					<td>
						<select name="rdeck_theme_options[num_featured]">
							<?php
								$selected = $options['num_featured'];
								$p = '';
								$r = '';

								foreach ( $select_options as $option ) {
									$label = $option['label'];
									if ( $selected == $option['value'] ) // Make default first in list
										$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr( $option['value'] ) . "'>$label</option>";
									else
										$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr( $option['value'] ) . "'>$label</option>";
								}
								echo $p . $r;
							?>
						</select>
						<label class="description" for="rdeck_theme_options[num_featured]"><?php _e( 'Choose number of latest post display as featured', 'rdeck' ); ?></label>
					</td>
				</tr>
                
                <?php
				/**
				 * A footer textarea option
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Footer Copyright text', 'rdeck' ); ?></th>
					<td>
						<textarea id="rdeck_theme_options[footer]" class="large-text" cols="50" rows="10" name="rdeck_theme_options[footer]"><?php echo esc_textarea( $options['footer'] ); ?></textarea>
						<label class="description" for="rdeck_theme_options[footer]"><?php _e( 'Write the copyright text that will appear in the footer.', 'rdeck' ); ?></label>
					</td>
				</tr>
                
                
				<?php
				/**
				 * Analytics code textarea option
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Analytics code', 'rdeck' ); ?></th>
					<td>
						<textarea id="rdeck_theme_options[analytics]" class="large-text" cols="50" rows="10" name="rdeck_theme_options[analytics]"><?php echo esc_textarea( $options['analytics'] ); ?></textarea>
						<label class="description" for="rdeck_theme_options[analytics]"><?php _e( 'Paste your Google Analytics (or other tracking) code.', 'rdeck' ); ?></label>
					</td>
				</tr>
                
			</table>

			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e( 'Save Options', 'rdeck' ); ?>" />
			</p>
		</form>
	</div>
	
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function rdeck_theme_options_validate( $input ) {
	global $select_options;

	// Our checkbox value is either 0 or 1
	if ( ! isset( $input['social'] ) )
		$input['social'] = null;
	$input['social'] = ( $input['social'] == 1 ? 1 : 0 );
	
	if ( ! isset( $input['txt_logo'] ) )
		$input['txt_logo'] = null;
	$input['txt_logo'] = ( $input['txt_logo'] == 1 ? 1 : 0 );

	// Say our text option must be safe text with no HTML tags
	$input['twitter'] = wp_filter_nohtml_kses( $input['twitter'] );
	$input['dribbble'] = wp_filter_nohtml_kses( $input['dribbble'] );
	$input['facebook'] = wp_filter_nohtml_kses( $input['facebook'] );
	$input['feedburner'] = wp_filter_nohtml_kses( $input['feedburner'] );
	
	$input['custom_logo'] = wp_filter_nohtml_kses( $input['custom_logo'] );

	// Our select option must actually be in our array of select options
	if ( ! array_key_exists( $input['num_featured'], $select_options ) )
		$input['num_featured'] = null;


	// Say our textarea option must be safe text with the allowed tags for posts
	$input['analytics'] = $input['analytics'];
	$input['footer'] = $input['footer'];

	return $input;
}
